==> cv-library-react-web-0.1.4.tgz: package/src/components/ListView/ListView.styles.js <==
// Core component styles
const coreStyles = {
    cell: {
        paddingLeft: '0px',
        paddingRight: '0px',
        paddingTop: '0px',
        border: 'none',
    },

    column: {
        padding: '10px',
        height: '100%',
        width: '100%',
        whiteSpace: 'pre-wrap',
        lineHeight: 'normal',
        wordBreak: 'break-word',
    },

    container: {
        height: '500px',
        overflowY: 'auto',
        maxHeight: '100vh',
    },

    evenRows: {},

    filter: {
        display: 'inline-block',
        backgroundColor: '#ececec',
        pointerEvents: 'auto',
    },

    filterContainer: {
        position: 'sticky',
        top: '0px',
        overflowX: 'hidden',
        pointerEvents: 'auto',
        borderBottomLeftRadius: '15px',
        borderBottomRightRadius: '15px',
        boxShadow: '5px 5px 8px #888888',
    },

    grid: {},

    headerCell: {
        cursor: 'auto',
        borderRight: '1px solid #e2e2e2',
        paddingLeft: '5px',
        paddingRight: '5px',
    },

    headerText: {},

    oddRows: {},

    row: {},

    rowSelected: {},
};

/**
 * Combines coreStyles and contextStyles
 * @param {Object} contextStyles
 */
const getStyles = (contextStyles) => {
    return {
        cell: {
            ...coreStyles.cell,
            ...contextStyles.cell,
        },

        column: {
            ...coreStyles.column,
            ...contextStyles.column,
        },

        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        evenRows: {
            ...coreStyles.evenRows,
            ...contextStyles.evenRows,
        },

        filter: {
            ...coreStyles.filter,
            ...contextStyles.filter,
        },

        filterContainer: {
            ...coreStyles.filterContainer,
            ...contextStyles.filterContainer,
        },

        grid: {
            ...coreStyles.grid,
            ...contextStyles.grid,
        },

        headerCell: {
            ...coreStyles.headerCell,
            ...contextStyles.headerCell,
        },

        headerText: {
            ...coreStyles.headerText,
            ...contextStyles.headerText,
        },

        oddRows: {
            ...coreStyles.oddRows,
            ...contextStyles.oddRows,
        },

        row: {
            ...coreStyles.row,
            ...contextStyles.row,
        },

        rowSelected: {
            ...coreStyles.rowSelected,
            ...contextStyles.rowSelected,
        },
    };
};

export default getStyles;

==> cv-library-react-web-0.1.14.tgz: package/src/components/ListView/ListView.styles.js <==
// Core component styles
const coreStyles = {
    cell: {
        paddingLeft: '0px',
        paddingRight: '0px',
        paddingTop: '0px',
        border: 'none',
    },

    column: {
        padding: '10px',
        height: '100%',
        width: '100%',
        whiteSpace: 'pre-wrap',
        lineHeight: 'normal',
        wordBreak: 'break-word',
    },

    container: {
        height: '500px',
        overflowY: 'auto',
        maxHeight: '100vh',
    },

    evenRows: {},

    filter: {
        display: 'inline-block',
        backgroundColor: '#ececec',
        pointerEvents: 'auto',
    },

    filterContainer: {
        position: 'sticky',
        top: '0px',
        overflowX: 'hidden',
        pointerEvents: 'auto',
        borderBottomLeftRadius: '15px',
        borderBottomRightRadius: '15px',
        boxShadow: '5px 5px 8px #888888',
    },

    grid: {},

    headerCell: {
        cursor: 'auto',
        borderRight: '1px solid #e2e2e2',
        paddingLeft: '5px',
        paddingRight: '5px',
    },

    headerText: {},

    oddRows: {},

    row: {},

    rowSelected: {},
};

/**
 * Combines coreStyles and contextStyles
 * @param {Object} contextStyles
 */
const getStyles = (contextStyles = {}) => {
    return {
        cell: {
            ...coreStyles.cell,
            ...contextStyles.cell,
        },

        column: {
            ...coreStyles.column,
            ...contextStyles.column,
        },

        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        evenRows: {
            ...coreStyles.evenRows,
            ...contextStyles.evenRows,
        },

        filter: {
            ...coreStyles.filter,
            ...contextStyles.filter,
        },

        filterContainer: {
            ...coreStyles.filterContainer,
            ...contextStyles.filterContainer,
        },

        grid: {
            ...coreStyles.grid,
            ...contextStyles.grid,
        },

        headerCell: {
            ...coreStyles.headerCell,
            ...contextStyles.headerCell,
        },

        headerText: {
            ...coreStyles.headerText,
            ...contextStyles.headerText,
        },

        oddRows: {
            ...coreStyles.oddRows,
            ...contextStyles.oddRows,
        },

        row: {
            ...coreStyles.row,
            ...contextStyles.row,
        },

        rowSelected: {
            ...coreStyles.rowSelected,
            ...contextStyles.rowSelected,
        },
    };
};

export default getStyles;
